md5 : cddd915074745db7c05180565b87f355
name : BAR_cddd
version : ""
language : C
language_id : C
installed : 0
date_compiled : Thu Jun 26 09:13:47 2014
inline_version : 0.5301
ILSM : %
    module : Inline::C
    suffix : so
    type : compiled
Config : %
    apiversion : ?
    archname : x86_64-linux
    cc : cc
    ccflags : -fno-strict-aliasing -pipe -fstack-protector -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64
    ld : cc
    osname : linux
    osvers : 3.5.0-39-generic
    so : so
    version : 5.18.1
